<?php

/**
 * Implementation of hook_profile_modules().
 */
function drupal_wiki_profile_modules() {
  $modules = array(
      'block', 'book', 'color', 'comment', 'search', 'taxonomy',
      'statistics', 'system', 'help', 'menu', 'node', 'path', 'user', 'dblog',

      // Additional for Wiki
      'admin_menu', 'diff', 'extlink', 'edit_section', 'filter', 'freelinking',
      'token', 'talk', 'pathauto', 'wikitools', 'wysiwyg', 'flexifilter',
  );

  return $modules;
}

/*
 * Install some modules later to avoid installation hangs.
 */

function _drupal_wiki_additional_modules() {
  return array(
      // Tools that glue the site together after install.
      'ctools',
      'features',
      'strongarm',
      // Custom features to implement the site.
      'wiki_content_type',
      'wiki_freelinking',
      'wiki_pathauto',
      'wiki_wikitools',
  );
}

/**
 * Implementation of hook_profile_details().
 */
function drupal_wiki_profile_details() {
  return array(
      'name' => 'Drupal wiki',
      'description' => 'Select this profile to create a wiki powered by Drupal.',
  );
}

/**
 * Perform any final installation tasks for this profile.
 *
 * The installer goes through the profile-select -> locale-select
 * -> requirements -> database -> profile-install-batch
 * -> locale-initial-batch -> configure -> locale-remaining-batch
 * -> finished -> done tasks, in this order, if you don't implement
 * this function in your profile.
 *
 * If this function is implemented, you can have any number of
 * custom tasks to perform after 'configure', implementing a state
 * machine here to walk the user through those tasks. First time,
 * this function gets called with $task set to 'profile', and you
 * can advance to further tasks by setting $task to your tasks'
 * identifiers, used as array keys in the hook_profile_task_list()
 * above. You must avoid the reserved tasks listed in
 * install_reserved_tasks(). If you implement your custom tasks,
 * this function will get called in every HTTP request (for form
 * processing, printing your information screens and so on) until
 * you advance to the 'profile-finished' task, with which you
 * hand control back to the installer. Each custom page you
 * return needs to provide a way to continue, such as a form
 * submission or a link. You should also set custom page titles.
 *
 * You should define the list of custom tasks you implement by
 * returning an array of them in hook_profile_task_list(), as these
 * show up in the list of tasks on the installer user interface.
 *
 * Remember that the user will be able to reload the pages multiple
 * times, so you might want to use variable_set() and variable_get()
 * to remember your data and control further processing, if $task
 * is insufficient. Should a profile want to display a form here,
 * it can; the form should set '#redirect' to FALSE, and rely on
 * an action in the submit handler, such as variable_set(), to
 * detect submission and proceed to further tasks. See the configuration
 * form handling code in install_tasks() for an example.
 *
 * Important: Any temporary variables should be removed using
 * variable_del() before advancing to the 'profile-finished' phase.
 *
 * @param $task
 *   The current $task of the install system. When hook_profile_tasks()
 *   is first called, this is 'profile'.
 * @param $url
 *   Complete URL to be used for a link or form action on a custom page,
 *   if providing any, to allow the user to proceed with the installation.
 *
 * @return
 *   An optional HTML string to display to the user. Only used if you
 *   modify the $task, otherwise discarded.
 */
function drupal_wiki_profile_tasks(&$task, $url) {

  // Insert default user-defined node types into the database. For a complete
  // list of available node type attributes, refer to the node type API
  // documentation at: http://api.drupal.org/api/HEAD/function/hook_node_info.

  global $profile, $install_locale;

  $output = "";
  
  require_once('profiles/default/default.profile');

  if ($task == 'profile') {

    $types = array(
        array(
            'type' => 'page',
            'name' => st('Page'),
            'module' => 'node',
            'description' => st("A <em>page</em>, similar in form to a <em>story</em>, is a simple method for creating and displaying information that rarely changes, such as an \"About us\" section of a website. By default, a <em>page</em> entry does not allow visitor comments and is not featured on the site's initial home page."),
            'custom' => TRUE,
            'modified' => TRUE,
            'locked' => FALSE,
            'help' => '',
            'min_word_count' => '',
        ),
        array(
            'type' => 'story',
            'name' => st('Story'),
            'module' => 'node',
            'description' => st("A <em>story</em>, similar in form to a <em>page</em>, is ideal for creating and displaying content that informs or engages website visitors. Press releases, site announcements, and informal blog-like entries may all be created with a <em>story</em> entry. By default, a <em>story</em> entry is automatically featured on the site's initial home page, and provides the ability to post comments."),
            'custom' => TRUE,
            'modified' => TRUE,
            'locked' => FALSE,
            'help' => '',
            'min_word_count' => '',
        ),
    );

    foreach ($types as $type) {
      $type = (object) _node_type_set_defaults($type);
      node_type_save($type);
    }

    // Enable much of the architecture via features.
    watchdog('drupal_wiki', 'enabling feature modules');
    $modules = _drupal_wiki_additional_modules();
    foreach ($modules as $module) {
      _drupal_install_module($module);
      module_enable(array($module));
    }

    // Set various variables.
    variable_set('anonymous', 'Anonymous');
    variable_set('clean_url', '1');
    variable_set('comment_book', '2');
    variable_set('comment_page', 0);
    variable_set('comment_talk_wiki', 1);
    variable_set('filter_html_1', 1);

    variable_set('menu_primary_menu', 2);
    variable_set('menu_secondary_menu', 2);
    variable_set('node_options_wiki', array(
        0 => 'status',
        1 => 'revision',
    ));

    variable_set('node_options_book', array(
        0 => 'status',
        1 => 'revision',
    ));
    variable_set('node_options_forum', array(
        0 => 'status',
    ));
    variable_set('node_options_page', array(
        0 => 'status',
    ));

    variable_set('show_preview_changes_book', 1);

    system_theme_data();

    // Add role "Moderator".
    db_query("INSERT INTO {role} (`rid`, `name`) VALUES (3, '%s')", 'moderator');
    
    // Add Wiki Filter
    db_query("INSERT INTO {filter_formats} (name, roles, cache) VALUES ('%s', '%s', %d)", 'Wiki', ',' . DRUPAL_AUTHENTICATED_RID . ',3,', 1);
    $wiki_format = db_last_insert_id('filter_formats', 'format');
  
    // URL filter.
    db_query("INSERT INTO {filters} (format, module, delta, weight) VALUES (%d, '%s', %d, %d)", $wiki_format, 'filter', 2, -9);
    // Line break filter.
    db_query("INSERT INTO {filters} (format, module, delta, weight) VALUES (%d, '%s', %d, %d)", $wiki_format, 'filter', 1, -8);
    // HTML corrector filter.
    db_query("INSERT INTO {filters} (format, module, delta, weight) VALUES (%d, '%s', %d, %d)", $wiki_format, 'filter', 3, -7);
    db_query("INSERT INTO {filters} (format, module, delta, weight) VALUES (%d, '%s', %d, %d)", $wiki_format, 'freelinking', 0, -10);
    variable_set('filter_default_format', $wiki_format);
    
  
    // Set access permissions for different roles
    db_query("UPDATE {permission} SET perm = 'create wiki content, edit any wiki content, edit own wiki content, access comments, post comments, post comments without approval, access content, revert revisions, view revisions, search content, use advanced search, access user profiles' WHERE rid = 1");
    db_query("UPDATE {permission} SET perm = 'create wiki content, edit any wiki content, edit own wiki content, access comments, post comments, post comments without approval, access content, revert revisions, view revisions, search content, use advanced search, access user profiles, change own username' WHERE rid = 2");
    db_query("INSERT INTO {permission} (`rid`, `perm`, `tid`) VALUES (3, 'create wiki content, edit any wiki content, edit own wiki content, access comments, administer comments, post comments, post comments without approval, access freelinking list, access content, revert revisions, view revisions, search content, use advanced search, access user profiles, administer users, change own username', 0)");
    // Add admin user with password 'admin'
    db_query("INSERT INTO {users} (`uid`, `name`, `pass`, `mail`, `mode`, `sort`, `threshold`, `theme`, `signature`, `created`, `access`, `login`, `status`, `timezone`, `language`, `picture`, `init`, `data`) VALUES (2, 'moderator', MD5('moderator'), '', 0, 0, 0, '', '', NOW(), NOW(), 0, 1, NULL, '', '', '', NULL)");

    // Update the menu router information.
    menu_rebuild();
    // Hand control back to installer.
    module_rebuild_cache();
    drupal_flush_all_caches();
    features_rebuild();
    $task = 'profile-finished';
    $output = "Site structure built.";

    // Add freelinking filter
    db_query("INSERT INTO {filters} (`format`, `module`, `delta`, `weight`) VALUES (%d, 'freelinking', 0, 10)", 1);
    system_initialize_theme_blocks('garland');
  }
  return $output;
}
